/*
 *  Copyright 2008, China UnionPay Co., Ltd.  All right reserved.
 *
 *  THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF CHINA UNIONPAY CO.,
 *  LTD.  THE CONTENTS OF THIS FILE MAY NOT BE DISCLOSED TO THIRD
 *  PARTIES, COPIED OR DUPLICATED IN ANY FORM, IN WHOLE OR IN PART,
 *  WITHOUT THE PRIOR WRITTEN PERMISSION OF CHINA UNIONPAY CO., LTD.
 *
 *  $Id: ServiceLocate.java,v 1.1 2013/04/23 06:14:52 wangping Exp $
 *
 *  Function:
 *
 *    服务定位类。
 *
 *  Edit History:
 *
 *    2008/12/02 - Created by zhang_xm.
 */
package com.cup.ibsmgm.common;

import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

import javax.naming.InitialContext;
import javax.naming.NamingException;

import com.test.EjbTestService;



/**
 * ServiceLocate<br>
 * 服务定位类<br>
 * 
 * @author zhang_xm created on 2008-12-02
 */
public class ServiceLocate {

	private static ServiceLocate instance;

	private InitialContext initContext = null;

	private Properties properties = null;
	
	

			
	private Map<String, Object> cache = new HashMap<String, Object>();

	private ServiceLocate() {
		try {
			getInitContext();
		} catch (Exception e) {

		}
	}

	/**
	 * 返回该ServiceLocate的一个实例
	 * 
	 * @return 改类的唯一实例
	 */
	public static synchronized ServiceLocate getInstance() {
		if (instance == null) {
			instance = new ServiceLocate();
		}
		return instance;
	}

	/**
	 * 上下文环境初始化。<br>
	 * 
	 * @throws NamingException
	 */
	public InitialContext getInitContext() throws NamingException {
		if (initContext != null) {
			return initContext;
		}
		try {
			if (properties == null) {
				initContext = new InitialContext();
			} else {
				initContext = new InitialContext(properties);
			}
		} catch (Exception e) {
			e.printStackTrace(System.err);
			throw new NamingException(e.toString() + " " + e.getMessage());
		}
		return initContext;
	}

	/**
	 * 根据JNDI名字查找EJB对象。<br>
	 * 
	 * @throws NamingException
	 */
	private Object createEjb3Object(String JNDIName) throws NamingException {
		Object obj = cache.get(JNDIName);
		if (obj != null) {
			return obj;
		}

		obj = initContext.lookup(JNDIName);
		if (obj != null) {
			cache.put(JNDIName, obj);
		} else {
			throw new NamingException("Could not find " + JNDIName
					+ " in ServiceLocations");
		}
		return obj;
	}

	/**
	 * 取得持久化类接口。
	 */
	public EjbTestService getEjbTestService() {
		try {
			return (EjbTestService) createEjb3Object("EjbTest");
		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}

	

}
